@@ -916,7 +916,7 @@ httpdSendFile(httpd * server, request * r, const char *path)
     char *suffix;
     struct stat sbuf;
 
-    suffix = rindex(path, '.');
+    suffix = strrchr(path, '.');
     if (suffix != NULL) {
         if (strcasecmp(suffix, ".gif") == 0)
             strcpy(r->response.contentType, "image/gif");
